@@ -6,7 +6,7 @@ test_that('clean_bafs works', {
       clean_bafs('WA')
   })
 
-  skip_if(is.null(out), message = 'data did not download.')
+  skip_if(is.null(out) || length(out) == 0, message = 'data did not download.')
 
   expect_true('VTD' %in% names(out))
 })
